@@ -15,7 +15,6 @@
  */
 
 #include "aligncommand.h"
-#include "referencedb.h"
 
 //**********************************************************************************************************************
 vector<string> AlignCommand::setParameters(){	
@@ -31,7 +30,6 @@ vector<string> AlignCommand::setParameters(){
 		CommandParameter pgapextend("gapextend", "Number", "", "-2.0", "", "", "","",false,false); parameters.push_back(pgapextend);
 		CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
 		CommandParameter pflip("flip", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(pflip);
-		CommandParameter psave("save", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(psave);
 		CommandParameter pthreshold("threshold", "Number", "", "0.50", "", "", "","",false,false); parameters.push_back(pthreshold);
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
@@ -63,7 +61,6 @@ string AlignCommand::getHelpString(){
 		helpString += "The flip parameter is used to specify whether or not you want mothur to try the reverse complement if a sequence falls below the threshold.  The default is false.";
 		helpString += "The threshold is used to specify a cutoff at which an alignment is deemed 'bad' and the reverse complement may be tried. The default threshold is 0.50, meaning 50% of the bases are removed in the alignment.";
 		helpString += "If the flip parameter is set to true the reverse complement of the sequence is aligned and the better alignment is reported.";
-		helpString += "If the save parameter is set to true the reference sequences will be saved in memory, to clear them later you can use the clear.memory command. Default=f.";
 		helpString += "The default for the threshold parameter is 0.50, meaning at least 50% of the bases must remain or the sequence is reported as potentially reversed.";
 		helpString += "The align.seqs command should be in the following format:";
 		helpString += "align.seqs(reference=yourTemplateFile, fasta=yourCandidateFile, align=yourAlignmentMethod, search=yourSearchmethod, ksize=yourKmerSize, match=yourMatchBonus, mismatch=yourMismatchpenalty, gapopen=yourGapopenPenalty, gapextend=yourGapExtendPenalty)";
@@ -112,7 +109,6 @@ AlignCommand::AlignCommand(){
 AlignCommand::AlignCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;
-		ReferenceDB* rdb = ReferenceDB::getInstance();
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true;}
@@ -261,28 +257,12 @@ AlignCommand::AlignCommand(string option)  {
 			m->mothurConvert(temp, processors); 
 			
 			temp = validParameter.validFile(parameters, "flip", false);			if (temp == "not found"){	temp = "f";				}
-			flip = m->isTrue(temp); 
-			
-			temp = validParameter.validFile(parameters, "save", false);			if (temp == "not found"){	temp = "f";				}
-			save = m->isTrue(temp); 
-			rdb->save = save; 
-			if (save) { //clear out old references
-				rdb->clearMemory();
-			}
+			flip = m->isTrue(temp);
 			
 			//this has to go after save so that if the user sets save=t and provides no reference we abort
 			templateFileName = validParameter.validFile(parameters, "reference", true);
-			if (templateFileName == "not found") { 
-				//check for saved reference sequences
-				if (rdb->referenceSeqs.size() != 0) {
-					templateFileName = "saved";
-				}else {
-					m->mothurOut("[ERROR]: You don't have any saved reference sequences and the reference parameter is a required for the align.seqs command."); 
-					m->mothurOutEndLine();
-					abort = true; 
-				}
+			if (templateFileName == "not found") { m->mothurOut("[ERROR]: The reference parameter is a required for the align.seqs command, aborting.\n"); abort = true;
 			}else if (templateFileName == "not open") { abort = true; }	
-			else {	if (save) {	rdb->setSavedReference(templateFileName);	}	}
 			
 			temp = validParameter.validFile(parameters, "threshold", false);	if (temp == "not found"){	temp = "0.50";			}
 			m->mothurConvert(temp, threshold); 
@@ -334,112 +314,6 @@ int AlignCommand::execute(){
 			for (int i = 0; i < lines.size(); i++) {  delete lines[i];  }  lines.clear();
 			int start = time(NULL);
 		
-#ifdef USE_MPI	
-				int pid, numSeqsPerProcessor; 
-				int tag = 2001;
-				vector<unsigned long long> MPIPos;
-				MPIWroteAccnos = false;
-			
-				MPI_Status status; 
-				MPI_Comm_rank(MPI_COMM_WORLD, &pid); //find out who we are
-				MPI_Comm_size(MPI_COMM_WORLD, &processors); 
-
-				MPI_File inMPI;
-				MPI_File outMPIAlign;
-				MPI_File outMPIReport;
-				MPI_File outMPIAccnos;
-				
-				int outMode=MPI_MODE_CREATE|MPI_MODE_WRONLY; 
-				int inMode=MPI_MODE_RDONLY; 
-				
-				char outAlignFilename[1024];
-				strcpy(outAlignFilename, alignFileName.c_str());
-				
-				char outReportFilename[1024];
-				strcpy(outReportFilename, reportFileName.c_str());
-				
-				char outAccnosFilename[1024];
-				strcpy(outAccnosFilename, accnosFileName.c_str());
-				
-				char inFileName[1024];
-				strcpy(inFileName, candidateFileNames[s].c_str());
-				
-				MPI_File_open(MPI_COMM_WORLD, inFileName, inMode, MPI_INFO_NULL, &inMPI);  //comm, filename, mode, info, filepointer
-				MPI_File_open(MPI_COMM_WORLD, outAlignFilename, outMode, MPI_INFO_NULL, &outMPIAlign);
-				MPI_File_open(MPI_COMM_WORLD, outReportFilename, outMode, MPI_INFO_NULL, &outMPIReport);
-				MPI_File_open(MPI_COMM_WORLD, outAccnosFilename, outMode, MPI_INFO_NULL, &outMPIAccnos);
-				
-				if (m->control_pressed) { MPI_File_close(&inMPI);  MPI_File_close(&outMPIAlign);  MPI_File_close(&outMPIReport);  MPI_File_close(&outMPIAccnos); outputTypes.clear(); return 0; }
-				
-				if (pid == 0) { //you are the root process 
-					
-					MPIPos = m->setFilePosFasta(candidateFileNames[s], numFastaSeqs); //fills MPIPos, returns numSeqs
-					
-					//send file positions to all processes
-					for(int i = 1; i < processors; i++) { 
-						MPI_Send(&numFastaSeqs, 1, MPI_INT, i, tag, MPI_COMM_WORLD);
-						MPI_Send(&MPIPos[0], (numFastaSeqs+1), MPI_LONG, i, tag, MPI_COMM_WORLD);
-					}
-					
-					//figure out how many sequences you have to align
-					numSeqsPerProcessor = numFastaSeqs / processors;
-					int startIndex =  pid * numSeqsPerProcessor;
-					if(pid == (processors - 1)){	numSeqsPerProcessor = numFastaSeqs - pid * numSeqsPerProcessor; 	}
-					
-					//align your part
-					driverMPI(startIndex, numSeqsPerProcessor, inMPI, outMPIAlign, outMPIReport, outMPIAccnos, MPIPos);
-					
-					if (m->control_pressed) { MPI_File_close(&inMPI);  MPI_File_close(&outMPIAlign);  MPI_File_close(&outMPIReport);  MPI_File_close(&outMPIAccnos); outputTypes.clear(); return 0; }
-
-					for (int i = 1; i < processors; i++) {
-						bool tempResult;
-						MPI_Recv(&tempResult, 1, MPI_INT, i, tag, MPI_COMM_WORLD, &status);
-						if (tempResult != 0) { MPIWroteAccnos = true; }
-					}
-				}else{ //you are a child process
-					MPI_Recv(&numFastaSeqs, 1, MPI_INT, 0, tag, MPI_COMM_WORLD, &status);
-					MPIPos.resize(numFastaSeqs+1);
-					MPI_Recv(&MPIPos[0], (numFastaSeqs+1), MPI_LONG, 0, tag, MPI_COMM_WORLD, &status);
-
-					
-					//figure out how many sequences you have to align
-					numSeqsPerProcessor = numFastaSeqs / processors;
-					int startIndex =  pid * numSeqsPerProcessor;
-					if(pid == (processors - 1)){	numSeqsPerProcessor = numFastaSeqs - pid * numSeqsPerProcessor; 	}
-					
-					
-					//align your part
-					driverMPI(startIndex, numSeqsPerProcessor, inMPI, outMPIAlign, outMPIReport, outMPIAccnos, MPIPos);
-					
-					if (m->control_pressed) { MPI_File_close(&inMPI);  MPI_File_close(&outMPIAlign);  MPI_File_close(&outMPIReport);  MPI_File_close(&outMPIAccnos); outputTypes.clear(); return 0; }
-
-					MPI_Send(&MPIWroteAccnos, 1, MPI_INT, 0, tag, MPI_COMM_WORLD); 
-				}
-				
-				//close files 
-				MPI_File_close(&inMPI);
-				MPI_File_close(&outMPIAlign);
-				MPI_File_close(&outMPIReport);
-				MPI_File_close(&outMPIAccnos);
-				
-				//delete accnos file if blank
-				if (pid == 0) {
-					//delete accnos file if its blank else report to user
-					if (MPIWroteAccnos) { 
-						m->mothurOut("Some of you sequences generated alignments that eliminated too many bases, a list is provided in " + accnosFileName + ".");
-						if (!flip) {
-							m->mothurOut(" If you set the flip parameter to true mothur will try aligning the reverse compliment as well."); 
-						}else{  m->mothurOut(" If the reverse compliment proved to be better it was reported.");  }
-						m->mothurOutEndLine();
-					}else { 
-						//MPI_Info info;
-						//MPI_File_delete(outAccnosFilename, info);
-						hasAccnos = false;	
-						m->mothurRemove(accnosFileName); 
-					}
-				}
-				
-#else
 
 			vector<unsigned long long> positions; 
 		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
@@ -450,7 +324,7 @@ int AlignCommand::execute(){
 				lines.push_back(new linePair(0, 1000));
 			}else {
 				positions = m->setFilePosFasta(candidateFileNames[s], numFastaSeqs); 
-				if (positions.size() < processors) { processors = positions.size(); }
+				if (numFastaSeqs < processors) { processors = numFastaSeqs; }
                 
 				//figure out how many sequences you have to process
 				int numSeqsPerProcessor = numFastaSeqs / processors;
@@ -473,29 +347,16 @@ int AlignCommand::execute(){
 			//delete accnos file if its blank else report to user
 			if (m->isBlank(accnosFileName)) {  m->mothurRemove(accnosFileName);  hasAccnos = false; }
 			else { 
-				m->mothurOut("Some of you sequences generated alignments that eliminated too many bases, a list is provided in " + accnosFileName + ".");
+				m->mothurOut("[WARNING]: Some of your sequences generated alignments that eliminated too many bases, a list is provided in " + accnosFileName + ".");
 				if (!flip) {
 					m->mothurOut(" If you set the flip parameter to true mothur will try aligning the reverse compliment as well."); 
 				}else{  m->mothurOut(" If the reverse compliment proved to be better it was reported.");  }
 				m->mothurOutEndLine();
 			}
 
-#endif		
-
-
-		#ifdef USE_MPI
-			MPI_Comm_rank(MPI_COMM_WORLD, &pid); 
-					
-			if (pid == 0) { //only one process should output to screen
-		#endif
-
 			outputNames.push_back(alignFileName); outputTypes["fasta"].push_back(alignFileName);
 			outputNames.push_back(reportFileName); outputTypes["alignreport"].push_back(reportFileName);
 			if (hasAccnos)	{	outputNames.push_back(accnosFileName);	outputTypes["accnos"].push_back(accnosFileName);  }
-			
-		#ifdef USE_MPI
-			}
-		#endif
 
 			m->mothurOut("It took " + toString(time(NULL) - start) + " secs to align " + toString(numFastaSeqs) + " sequences.");
 			m->mothurOutEndLine();
@@ -675,186 +536,6 @@ int AlignCommand::driver(linePair* filePos, string alignFName, string reportFNam
 		exit(1);
 	}
 }
-//**********************************************************************************************************************
-#ifdef USE_MPI
-int AlignCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File& alignFile, MPI_File& reportFile, MPI_File& accnosFile, vector<unsigned long long>& MPIPos){
-	try {
-		string outputString = "";
-		MPI_Status statusReport; 
-		MPI_Status statusAlign; 
-		MPI_Status statusAccnos; 
-		MPI_Status status; 
-		int pid;
-		MPI_Comm_rank(MPI_COMM_WORLD, &pid); //find out who we are
-	
-		NastReport report;
-		
-		if (pid == 0) {
-			outputString = report.getHeaders();
-			int length = outputString.length();
-            
-			char* buf = new char[length];
-			memcpy(buf, outputString.c_str(), length);
-		
-			MPI_File_write_shared(reportFile, buf, length, MPI_CHAR, &statusReport);
-
-            delete buf;
-		}
-		
-		Alignment* alignment;
-		int longestBase = templateDB->getLongestBase();
-		if(align == "gotoh")			{	alignment = new GotohOverlap(gapOpen, gapExtend, match, misMatch, longestBase);			}
-		else if(align == "needleman")	{	alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);				}
-		else if(align == "blast")		{	alignment = new BlastAlignment(gapOpen, gapExtend, match, misMatch);		}
-		else if(align == "noalign")		{	alignment = new NoAlign();													}
-		else {
-			m->mothurOut(align + " is not a valid alignment option. I will run the command using needleman.");
-			m->mothurOutEndLine();
-			alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);
-		}
-		
-		
-		for(int i=0;i<num;i++){
-		
-			if (m->control_pressed) { delete alignment; return 0; }
-
-			//read next sequence
-			int length = MPIPos[start+i+1] - MPIPos[start+i];
-
-			char* buf4 = new char[length];
-			//memcpy(buf4, outputString.c_str(), length);
-
-			MPI_File_read_at(inMPI, MPIPos[start+i], buf4, length, MPI_CHAR, &status);
-			
-			string tempBuf = buf4;
-
-			delete buf4;
-
-			if (tempBuf.length() > length) { tempBuf = tempBuf.substr(0, length);  }
-	
-			istringstream iss (tempBuf,istringstream::in);
-
-			Sequence* candidateSeq = new Sequence(iss);  
-			report.setCandidate(candidateSeq);
-
-			int origNumBases = candidateSeq->getNumBases();
-			string originalUnaligned = candidateSeq->getUnaligned();
-			int numBasesNeeded = origNumBases * threshold;
-	
-			if (candidateSeq->getName() != "") { //incase there is a commented sequence at the end of a file
-				if (candidateSeq->getUnaligned().length() > alignment->getnRows()) {
-					alignment->resize(candidateSeq->getUnaligned().length()+1);
-				}
-								
-				Sequence temp = templateDB->findClosestSequence(candidateSeq);
-				Sequence* templateSeq = new Sequence(temp.getName(), temp.getAligned());
-				
-				float searchScore = templateDB->getSearchScore();
-								
-				Nast* nast = new Nast(alignment, candidateSeq, templateSeq);
-				Sequence* copy;
-				
-				Nast* nast2;
-				bool needToDeleteCopy = false;  //this is needed in case you have you enter the ifs below
-												//since nast does not make a copy of hte sequence passed, and it is used by the reporter below
-												//you can't delete the copy sequence til after you report, but you may choose not to create it in the first place
-												//so this bool tells you if you need to delete it
-												
-				//if there is a possibility that this sequence should be reversed
-				if (candidateSeq->getNumBases() < numBasesNeeded) {
-					
-					string wasBetter = "";
-					//if the user wants you to try the reverse
-					if (flip) {
-						//get reverse compliment
-						copy = new Sequence(candidateSeq->getName(), originalUnaligned);
-						copy->reverseComplement();
-						
-						//rerun alignment
-						Sequence temp2 = templateDB->findClosestSequence(copy);
-						Sequence* templateSeq2 = new Sequence(temp2.getName(), temp2.getAligned());
-						
-						searchScore = templateDB->getSearchScore();
-						
-						nast2 = new Nast(alignment, copy, templateSeq2);
-			
-						//check if any better
-						if (copy->getNumBases() > candidateSeq->getNumBases()) {
-							candidateSeq->setAligned(copy->getAligned());  //use reverse compliments alignment since its better
-							delete templateSeq;
-							templateSeq = templateSeq2;
-							delete nast;
-							nast = nast2;
-							needToDeleteCopy = true;
-							wasBetter = "\treverse complement produced a better alignment, so mothur used the reverse complement.";
-						}else{  
-							wasBetter = "\treverse complement did NOT produce a better alignment, please check sequence.";
-							delete nast2;
-                            delete templateSeq2;
-							delete copy;	
-						}
-					}
-					
-					//create accnos file with names
-					outputString = candidateSeq->getName() + wasBetter + "\n";
-					
-					//send results to parent
-					int length = outputString.length();
-
-					char* buf = new char[length];
-					memcpy(buf, outputString.c_str(), length);
-				
-					MPI_File_write_shared(accnosFile, buf, length, MPI_CHAR, &statusAccnos);
-					delete buf;
-					MPIWroteAccnos = true;
-				}
-				
-				report.setTemplate(templateSeq);
-				report.setSearchParameters(search, searchScore);
-				report.setAlignmentParameters(align, alignment);
-				report.setNastParameters(*nast);
-	
-				outputString =  ">" + candidateSeq->getName() + "\n" + candidateSeq->getAligned() + "\n";
-				
-				//send results to parent
-				int length = outputString.length();
-				char* buf2 = new char[length];
-				memcpy(buf2, outputString.c_str(), length);
-				
-				MPI_File_write_shared(alignFile, buf2, length, MPI_CHAR, &statusAlign);
-				
-				delete buf2;
-
-				outputString = report.getReport();
-				
-				//send results to parent
-				length = outputString.length();
-				char* buf3 = new char[length];
-				memcpy(buf3, outputString.c_str(), length);
-				
-				MPI_File_write_shared(reportFile, buf3, length, MPI_CHAR, &statusReport);
-				
-				delete buf3;
-				delete nast;
-                delete templateSeq;
-				if (needToDeleteCopy) {   delete copy;   }
-			}
-			delete candidateSeq;
-			
-			//report progress
-			if((i+1) % 100 == 0){	cout << (toString(i+1)) << endl;		}
-		}
-		//report progress
-		if((num) % 100 != 0){	cout << (toString(num)) << endl;		}
-		
-		return 1;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "AlignCommand", "driverMPI");
-		exit(1);
-	}
-}
-#endif
 /**************************************************************************************************/
 
 int AlignCommand::createProcesses(string alignFileName, string reportFileName, string accnosFName, string filename) {
