@@ -9,9 +9,7 @@
 
 #include "chimerauchimecommand.h"
 #include "deconvolutecommand.h"
-//#include "uc.h"
 #include "sequence.hpp"
-#include "referencedb.h"
 #include "systemcommand.h"
 
 //**********************************************************************************************************************
@@ -90,9 +88,6 @@ string ChimeraUchimeCommand::getHelpString(){
 		helpString += "The maxlen parameter is the maximum unaligned sequence length. Defaults 10000. Applies to both query and reference sequences.\n";
 		helpString += "The ucl parameter - use local-X alignments. Default is global-X or false. On tests so far, global-X is always better; this option is retained because it just might work well on some future type of data.\n";
 		helpString += "The queryfract parameter - minimum fraction of the query sequence that must be covered by a local-X alignment. Default 0.5. Applies only when ucl is true.\n";
-#ifdef USE_MPI
-		helpString += "When using MPI, the processors parameter is set to the number of MPI processes running. \n";
-#endif
 		helpString += "The chimera.uchime command should be in the following format: \n";
 		helpString += "chimera.uchime(fasta=yourFastaFile, reference=yourTemplate) \n";
 		helpString += "Example: chimera.uchime(fasta=AD.align, reference=silva.gold.align) \n";
@@ -142,7 +137,6 @@ ChimeraUchimeCommand::ChimeraUchimeCommand(){
 ChimeraUchimeCommand::ChimeraUchimeCommand(string option)  {
 	try {
 		abort = false; calledHelp = false; hasName=false; hasCount=false;
-		ReferenceDB* rdb = ReferenceDB::getInstance();
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -503,27 +497,15 @@ ChimeraUchimeCommand::ChimeraUchimeCommand(string option)  {
 					templatefile = validParameter.validFile(parameters, "reference", true);
 					if (templatefile == "not open") { abort = true; }
 					else if (templatefile == "not found") { //check for saved reference sequences
-						if (rdb->getSavedReference() != "") {
-							templatefile = rdb->getSavedReference();
-							m->mothurOutEndLine();  m->mothurOut("Using sequences from " + rdb->getSavedReference() + ".");	m->mothurOutEndLine();
-						}else {
-							m->mothurOut("[ERROR]: You don't have any saved reference sequences and the reference parameter is a required."); 
-							m->mothurOutEndLine();
-							abort = true; 
-						}
+						m->mothurOut("[ERROR]: The reference parameter is a required.\n"); abort = true;
 					}
 				}
 			}else if (hasName) {  templatefile = "self"; }
             else if (hasCount) {  templatefile = "self"; }
-			else { 
-				if (rdb->getSavedReference() != "") {
-					templatefile = rdb->getSavedReference();
-					m->mothurOutEndLine();  m->mothurOut("Using sequences from " + rdb->getSavedReference() + ".");	m->mothurOutEndLine();
-				}else {
-					m->mothurOut("[ERROR]: You don't have any saved reference sequences and the reference parameter is a required."); 
-					m->mothurOutEndLine();
-					templatefile = ""; abort = true; 
-				} 
+			else {
+                m->mothurOut("[ERROR]: The reference parameter is a required.");
+					
+                templatefile = ""; abort = true;
 			}
 				
 			string temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
@@ -693,7 +675,7 @@ int ChimeraUchimeCommand::execute(){
 				if (error == 1) { for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	}  return 0; }
 				if (seqs.size() != nameMapCount.size()) { m->mothurOut( "The number of sequences in your fastafile does not match the number of sequences in your namefile, aborting."); m->mothurOutEndLine(); for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	}  return 0; }
 				
-				printFile(nameMapCount, newFasta);
+                m->printVsearchFile(nameMapCount, newFasta, "/ab=", "/");
 				fastaFileNames[s] = newFasta;
 			}
 			
@@ -1102,29 +1084,7 @@ int ChimeraUchimeCommand::deconvoluteResults(map<string, string>& uniqueNames, s
 		m->errorOut(e, "ChimeraUchimeCommand", "deconvoluteResults");
 		exit(1);
 	}
-}	
-//**********************************************************************************************************************
-int ChimeraUchimeCommand::printFile(vector<seqPriorityNode>& nameMapCount, string filename){
-	try {
-		
-		sort(nameMapCount.begin(), nameMapCount.end(), compareSeqPriorityNodes);
-		
-		ofstream out;
-		m->openOutputFile(filename, out);
-		
-		//print new file in order of
-		for (int i = 0; i < nameMapCount.size(); i++) {
-			out << ">" << nameMapCount[i].name  << "/ab=" << nameMapCount[i].numIdentical << "/" << endl << nameMapCount[i].seq << endl;
-		}
-		out.close();
-		
-		return 0;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ChimeraUchimeCommand", "printFile");
-		exit(1);
-	}
-}	
+}		
 //**********************************************************************************************************************
 int ChimeraUchimeCommand::readFasta(string filename, map<string, string>& seqs){
 	try {
@@ -1197,8 +1157,8 @@ int ChimeraUchimeCommand::driverGroups(string outputFName, string filename, stri
 			int start = time(NULL);	 if (m->control_pressed) {  outCountList.close(); m->mothurRemove(countlist); return 0; }
             
 			int error;
-            if (hasCount) { error = cparser->getSeqs(groups[i], filename, true); if ((error == 1) || m->control_pressed) {  return 0; } }
-            else { error = sparser->getSeqs(groups[i], filename, true); if ((error == 1) || m->control_pressed) {  return 0; } }
+            if (hasCount) { error = cparser->getSeqs(groups[i], filename, "/ab=", "/", true); if ((error == 1) || m->control_pressed) {  return 0; } }
+            else { error = sparser->getSeqs(groups[i], filename, "/ab=", "/", true); if ((error == 1) || m->control_pressed) {  return 0; } }
 			
 			int numSeqs = driver((outputFName + groups[i]), filename, (accnos+groups[i]), (alns+ groups[i]), numChimeras);
 			totalSeqs += numSeqs;
@@ -1275,6 +1235,14 @@ int ChimeraUchimeCommand::driver(string outputFName, string filename, string acc
 		outputFName = "\"" + outputFName + "\"";
 		filename = "\"" + filename + "\"";
 		alns = "\"" + alns + "\"";
+        
+        if (filename.length() > 257) {
+            m->mothurOut("[ERROR]: " + filename + " filename is " + toString(filename.length()) + " long. The uchime program can't handle files with a full path longer than 257 characters, please correct.\n"); m->control_pressed = true; return 0;
+        }else if ((alns.length() > 257) && (chimealns)) {
+            m->mothurOut("[ERROR]: " + alns + " filename is " + toString(alns.length()) + " long. The uchime program can't handle files with a full path longer than 257 characters, please correct.\n"); m->control_pressed = true; return 0;
+        }else if (outputFName.length() > 257) {
+            m->mothurOut("[ERROR]: " + outputFName + " filename is " + toString(outputFName.length()) + " long. The uchime program can't handle files with a full path longer than 257 characters, please correct input file name.\n"); m->control_pressed = true; return 0;
+        }
 				
 		vector<char*> cPara;
 		
@@ -1524,7 +1492,7 @@ int ChimeraUchimeCommand::driver(string outputFName, string filename, string acc
 		//int numArgs = cPara.size();
 		
 		//uchime_main(numArgs, uchimeParameters); 
-		//cout << "commandString = " << commandString << endl;
+		
 #if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 #else
 		commandString = "\"" + commandString + "\"";
@@ -1691,40 +1659,29 @@ int ChimeraUchimeCommand::createProcesses(string outputFileName, string filename
 		//divide file
 		int count = 0;
 		int spot = 0;
-		map<int, ofstream*> filehandles;
-		map<int, ofstream*>::iterator it3;
 		
-		ofstream* temp;
 		for (int i = 0; i < processors; i++) {
-			temp = new ofstream;
-			filehandles[i] = temp;
-			m->openOutputFile(filename+toString(i)+".temp", *(temp));
-			files.push_back(filename+toString(i)+".temp");
+            ofstream temp;
+			files[i] = filename+toString(i)+".temp";
+			m->openOutputFile(filename+toString(i)+".temp", temp);
 		}
 		
 		ifstream in;
 		m->openInputFile(filename, in);
 		
 		while(!in.eof()) {
-			
-			if (m->control_pressed) { in.close(); for (it3 = filehandles.begin(); it3 != filehandles.end(); it3++) { (*(it3->second)).close(); delete it3->second; } return 0; }
-			
 			Sequence tempSeq(in); m->gobble(in); 
 			
 			if (tempSeq.getName() != "") {
-				tempSeq.printSequence(*(filehandles[spot])); 
+                ofstream temp;
+                m->openOutputFileAppend(files[spot], temp);
+                tempSeq.printSequence(temp); temp.close();
 				spot++; count++;
 				if (spot == processors) { spot = 0; }
 			}
 		}
 		in.close();
 		
-		//delete memory
-		for (it3 = filehandles.begin(); it3 != filehandles.end(); it3++) {
-			(*(it3->second)).close();
-			delete it3->second;
-		}
-		
 		//sanity check for number of processors
 		if (count < processors) { processors = count; }
 		
@@ -1782,6 +1739,7 @@ int ChimeraUchimeCommand::createProcesses(string outputFileName, string filename
 		
 		//get rid of the file pieces.
 		for (int i = 0; i < files.size(); i++) { m->mothurRemove(files[i]); }
+        
 		return num;	
 	}
 	catch(exception& e) {
