@@ -271,140 +271,7 @@ int DistanceCommand::execute(){
 			m->mothurRemove(outputFile);
 			outputTypes["phylip"].push_back(outputFile);
 		}
-		
 
-#ifdef USE_MPI
-		
-		int pid, start, end; 
-		int tag = 2001;
-				
-		MPI_Status status; 
-		MPI_Comm_size(MPI_COMM_WORLD, &processors); //set processors to the number of mpi processes running
-		MPI_Comm_rank(MPI_COMM_WORLD, &pid); //find out who we are
-		
-		//each process gets where it should start and stop in the file
-		if (output != "square") {
-			start = int (sqrt(float(pid)/float(processors)) * numSeqs);
-			end = int (sqrt(float(pid+1)/float(processors)) * numSeqs);
-		}else{
-			start = int ((float(pid)/float(processors)) * numSeqs);
-			end = int ((float(pid+1)/float(processors)) * numSeqs);
-		}
-		
-		if (output == "column") {
-			MPI_File outMPI;
-			int amode=MPI_MODE_CREATE|MPI_MODE_WRONLY; 
-
-			//char* filename = new char[outputFile.length()];
-			//memcpy(filename, outputFile.c_str(), outputFile.length());
-			
-			char filename[1024];
-			strcpy(filename, outputFile.c_str());
-			
-			MPI_File_open(MPI_COMM_WORLD, filename, amode, MPI_INFO_NULL, &outMPI);
-			//delete filename;
-
-			if (pid == 0) { //you are the root process 
-				
-				//do your part
-				string outputMyPart;
-				
-				driverMPI(start, end, outMPI, cutoff); 
-				
-				if (m->control_pressed) { outputTypes.clear(); MPI_File_close(&outMPI);   return 0; }
-			
-				//wait on chidren
-				for(int i = 1; i < processors; i++) { 
-					if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);    return 0; }
-					
-					char buf[5];
-					MPI_Recv(buf, 5, MPI_CHAR, i, tag, MPI_COMM_WORLD, &status); 
-				}
-			}else { //you are a child process
-				//do your part
-				driverMPI(start, end, outMPI, cutoff); 
-				
-				if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);   return 0; }
-			
-				char buf[5];
-				strcpy(buf, "done"); 
-				//tell parent you are done.
-				MPI_Send(buf, 5, MPI_CHAR, 0, tag, MPI_COMM_WORLD);
-			}
-			
-			MPI_File_close(&outMPI);
-			
-		}else { //lower triangle format
-			if (pid == 0) { //you are the root process 
-			
-				//do your part
-				string outputMyPart;
-				unsigned long long mySize;
-				
-				if (output != "square"){ driverMPI(start, end, outputFile, mySize); }
-				else { driverMPI(start, end, outputFile, mySize, output); }
-	
-				if (m->control_pressed) {  outputTypes.clear();   return 0; }
-				
-				int amode=MPI_MODE_APPEND|MPI_MODE_WRONLY|MPI_MODE_CREATE; //
-				MPI_File outMPI;
-				MPI_File inMPI;
-
-				//char* filename = new char[outputFile.length()];
-				//memcpy(filename, outputFile.c_str(), outputFile.length());
-				
-				char filename[1024];
-				strcpy(filename, outputFile.c_str());
-
-				MPI_File_open(MPI_COMM_SELF, filename, amode, MPI_INFO_NULL, &outMPI);
-				//delete filename;
-
-				//wait on chidren
-				for(int b = 1; b < processors; b++) { 
-					unsigned long long fileSize;
-					
-					if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);   return 0; }
-					
-					MPI_Recv(&fileSize, 1, MPI_LONG, b, tag, MPI_COMM_WORLD, &status); 
-					
-					string outTemp = outputFile + toString(b) + ".temp";
-
-					char* buf = new char[outTemp.length()];
-					memcpy(buf, outTemp.c_str(), outTemp.length());
-					
-					MPI_File_open(MPI_COMM_SELF, buf, MPI_MODE_DELETE_ON_CLOSE|MPI_MODE_RDONLY, MPI_INFO_NULL, &inMPI);
-					delete buf;
-
-					int count = 0;
-					while (count < fileSize) { 
-						char buf2[1];
-						MPI_File_read(inMPI, buf2, 1, MPI_CHAR, &status);
-						MPI_File_write(outMPI, buf2, 1, MPI_CHAR, &status);
-						count += 1;
-					}
-					
-					MPI_File_close(&inMPI); //deleted on close
-				}
-				
-				MPI_File_close(&outMPI);
-			}else { //you are a child process
-				//do your part
-				unsigned long long size;
-				if (output != "square"){ driverMPI(start, end, (outputFile + toString(pid) + ".temp"), size); }
-				else { driverMPI(start, end, (outputFile + toString(pid) + ".temp"), size, output); }
-				
-				if (m->control_pressed) {  return 0; }
-			
-				//tell parent you are done.
-				MPI_Send(&size, 1, MPI_LONG, 0, tag, MPI_COMM_WORLD);
-			}
-		}
-        
-        MPI_Barrier(MPI_COMM_WORLD); //make everyone wait - just in case
-        
-#else
-				
-	//#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 		//if you don't need to fork anything
 		if(processors == 1){
 			if (output != "square") {  driver(0, numSeqs, outputFile, cutoff); }
@@ -412,23 +279,9 @@ int DistanceCommand::execute(){
 		}else{ //you have multiple processors
 			createProcesses(outputFile, numSeqs);
 		}
-	//#else
-		//ifstream inFASTA;
-		//if (output != "square") {  driver(0, numSeqs, outputFile, cutoff); }
-		//else { driver(0, numSeqs, outputFile, "square");  }
-	//#endif
-	
-#endif
+
 		if (m->control_pressed) { outputTypes.clear();  m->mothurRemove(outputFile); return 0; }
 		
-		#ifdef USE_MPI
-			MPI_Comm_rank(MPI_COMM_WORLD, &pid); 
-					
-			if (pid == 0) { //only one process should output to screen
-		#endif
-		
-		//if (output == "square") {  convertMatrix(outputFile); }
-		
 		ifstream fileHandle;
 		fileHandle.open(outputFile.c_str());
 		if(fileHandle) {
@@ -456,11 +309,6 @@ int DistanceCommand::execute(){
 				outputFile = newOutputName;
 			}
 		}
-
-		
-		#ifdef USE_MPI
-			}
-		#endif
 		
 		if (m->control_pressed) { outputTypes.clear();  m->mothurRemove(outputFile); return 0; }
 		
@@ -816,453 +664,7 @@ int DistanceCommand::driver(int startLine, int endLine, string dFileName, string
 		exit(1);
 	}
 }
-#ifdef USE_MPI
 /**************************************************************************************************/
-/////// need to fix to work with calcs and sequencedb
-int DistanceCommand::driverMPI(int startLine, int endLine, MPI_File& outMPI, float cutoff){
-	try {
-		
-		ValidCalculators validCalculator;
-		Dist* distCalculator;
-		if (m->isTrue(countends) == true) {
-			for (int i=0; i<Estimators.size(); i++) {
-				if (validCalculator.isValidCalculator("distance", Estimators[i]) == true) { 
-					if (Estimators[i] == "nogaps")			{	distCalculator = new ignoreGaps();	}
-					else if (Estimators[i] == "eachgap")	{	distCalculator = new eachGapDist();	}
-					else if (Estimators[i] == "onegap")		{	distCalculator = new oneGapDist();	}
-				}
-			}
-		}else {
-			for (int i=0; i<Estimators.size(); i++) {
-				if (validCalculator.isValidCalculator("distance", Estimators[i]) == true) { 
-					if (Estimators[i] == "nogaps")		{	distCalculator = new ignoreGaps();					}
-					else if (Estimators[i] == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-					else if (Estimators[i] == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
-				}
-			}
-		}
-		
-		
-		MPI_Status status;
-		int startTime = time(NULL);
-		
-		string outputString = "";
-		
-		for(int i=startLine;i<endLine;i++){
-	
-			for(int j=0;j<i;j++){
-				
-				if (m->control_pressed) {  delete distCalculator; return 0;  }
-				
-				//if there was a column file given and we are appending, we don't want to calculate the distances that are already in the column file
-				//the alignDB contains the new sequences and then the old, so if i an oldsequence and j is an old sequence then break out of this loop
-				if ((i >= numNewFasta) && (j >= numNewFasta)) { break; }
-				
-				distCalculator->calcDist(alignDB.get(i), alignDB.get(j));
-				double dist = distCalculator->getDist();
-				
-				if(dist <= cutoff){
-					 outputString += (alignDB.get(i).getName() + ' ' + alignDB.get(j).getName() + ' ' + toString(dist) + '\n'); 
-				}
-			}
-			
-			if(i % 100 == 0){
-				m->mothurOutJustToScreen(toString(i) + "\t" + toString(time(NULL) - startTime)+"\n"); 
-			}
-			
-			 
-			//send results to parent
-			int length = outputString.length();
-
-			char* buf = new char[length];
-			memcpy(buf, outputString.c_str(), length);
-			
-			MPI_File_write_shared(outMPI, buf, length, MPI_CHAR, &status);
-			outputString = "";
-			delete buf;
-			
-		}
-		
-		m->mothurOutJustToScreen(toString(endLine-1) + "\t" + toString(time(NULL) - startTime)+"\n");
-		delete distCalculator;
-		return 1;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "DistanceCommand", "driverMPI");
-		exit(1);
-	}
-}
-/**************************************************************************************************/
-/////// need to fix to work with calcs and sequencedb
-int DistanceCommand::driverMPI(int startLine, int endLine, string file, unsigned long long& size){
-	try {
-		ValidCalculators validCalculator;
-		Dist* distCalculator;
-		if (m->isTrue(countends) == true) {
-			for (int i=0; i<Estimators.size(); i++) {
-				if (validCalculator.isValidCalculator("distance", Estimators[i]) == true) { 
-					if (Estimators[i] == "nogaps")			{	distCalculator = new ignoreGaps();	}
-					else if (Estimators[i] == "eachgap")	{	distCalculator = new eachGapDist();	}
-					else if (Estimators[i] == "onegap")		{	distCalculator = new oneGapDist();	}
-				}
-			}
-		}else {
-			for (int i=0; i<Estimators.size(); i++) {
-				if (validCalculator.isValidCalculator("distance", Estimators[i]) == true) { 
-					if (Estimators[i] == "nogaps")		{	distCalculator = new ignoreGaps();					}
-					else if (Estimators[i] == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-					else if (Estimators[i] == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
-				}
-			}
-		}
-		
-		
-		MPI_Status status;
-		
-		MPI_File outMPI;
-		int amode=MPI_MODE_CREATE|MPI_MODE_WRONLY; 
-
-		//char* filename = new char[file.length()];
-		//memcpy(filename, file.c_str(), file.length());
-		
-		char filename[1024];
-		strcpy(filename, file.c_str());
-
-		MPI_File_open(MPI_COMM_SELF, filename, amode, MPI_INFO_NULL, &outMPI);
-		//delete filename;
-
-		int startTime = time(NULL);
-		
-		string outputString = "";
-		size = 0;
-		
-		if(startLine == 0){	outputString += toString(alignDB.getNumSeqs()) + "\n";	}
-		
-		for(int i=startLine;i<endLine;i++){
-				
-			string name = alignDB.get(i).getName();
-			if (name.length() < 10) { //pad with spaces to make compatible
-				while (name.length() < 10) {  name += " ";  }
-			}
-			outputString += name;
-			
-			for(int j=0;j<i;j++){
-				
-				if (m->control_pressed) { delete distCalculator; return 0;  }
-				
-				distCalculator->calcDist(alignDB.get(i), alignDB.get(j));
-				double dist = distCalculator->getDist();
-				
-				outputString += "\t" + toString(dist);
-			}
-			
-			outputString += "\n"; 
-
-		
-			if(i % 100 == 0){
-				m->mothurOutJustToScreen(toString(i) + "\t" + toString(time(NULL) - startTime)+"\n"); 			}
-			
-			
-			//send results to parent
-			int length = outputString.length();
-			char* buf = new char[length];
-			memcpy(buf, outputString.c_str(), length);
-			
-			MPI_File_write(outMPI, buf, length, MPI_CHAR, &status);
-			size += outputString.length();
-			outputString = "";
-			delete buf;
-		}
-		
-		m->mothurOutJustToScreen(toString(endLine-1) + "\t" + toString(time(NULL) - startTime)+"\n");
-		
-		MPI_File_close(&outMPI);
-		delete distCalculator;
-		
-		return 1;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "DistanceCommand", "driverMPI");
-		exit(1);
-	}
-}
-/**************************************************************************************************/
-/////// need to fix to work with calcs and sequencedb
-int DistanceCommand::driverMPI(int startLine, int endLine, string file, unsigned long long& size, string square){
-	try {
-		ValidCalculators validCalculator;
-		Dist* distCalculator;
-		if (m->isTrue(countends) == true) {
-			for (int i=0; i<Estimators.size(); i++) {
-				if (validCalculator.isValidCalculator("distance", Estimators[i]) == true) { 
-					if (Estimators[i] == "nogaps")			{	distCalculator = new ignoreGaps();	}
-					else if (Estimators[i] == "eachgap")	{	distCalculator = new eachGapDist();	}
-					else if (Estimators[i] == "onegap")		{	distCalculator = new oneGapDist();	}
-				}
-			}
-		}else {
-			for (int i=0; i<Estimators.size(); i++) {
-				if (validCalculator.isValidCalculator("distance", Estimators[i]) == true) { 
-					if (Estimators[i] == "nogaps")		{	distCalculator = new ignoreGaps();					}
-					else if (Estimators[i] == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-					else if (Estimators[i] == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
-				}
-			}
-		}
-		
-		MPI_Status status;
-		
-		MPI_File outMPI;
-		int amode=MPI_MODE_CREATE|MPI_MODE_WRONLY; 
-
-		//char* filename = new char[file.length()];
-		//memcpy(filename, file.c_str(), file.length());
-		
-		char filename[1024];
-		strcpy(filename, file.c_str());
-
-		MPI_File_open(MPI_COMM_SELF, filename, amode, MPI_INFO_NULL, &outMPI);
-		//delete filename;
-
-		int startTime = time(NULL);
-		
-		string outputString = "";
-		size = 0;
-		
-		if(startLine == 0){	outputString += toString(alignDB.getNumSeqs()) + "\n";	}
-		
-		for(int i=startLine;i<endLine;i++){
-				
-			string name = alignDB.get(i).getName();
-			if (name.length() < 10) { //pad with spaces to make compatible
-				while (name.length() < 10) {  name += " ";  }
-			}
-			outputString += name;
-			
-			for(int j=0;j<alignDB.getNumSeqs();j++){
-				
-				if (m->control_pressed) { delete distCalculator; return 0;  }
-				
-				distCalculator->calcDist(alignDB.get(i), alignDB.get(j));
-				double dist = distCalculator->getDist();
-				
-				outputString += "\t" + toString(dist);
-			}
-			
-			outputString += "\n"; 
-
-		
-			if(i % 100 == 0){
-				m->mothurOutJustToScreen(toString(i) + "\t" + toString(time(NULL) - startTime)+"\n"); 
-			}
-			
-			
-			//send results to parent
-			int length = outputString.length();
-			char* buf = new char[length];
-			memcpy(buf, outputString.c_str(), length);
-			
-			MPI_File_write(outMPI, buf, length, MPI_CHAR, &status);
-			size += outputString.length();
-			outputString = "";
-			delete buf;
-		}
-		
-		m->mothurOutJustToScreen(toString(endLine-1) + "\t" + toString(time(NULL) - startTime)+"\n");
-		
-		MPI_File_close(&outMPI);
-		delete distCalculator;
-		return 1;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "DistanceCommand", "driverMPI");
-		exit(1);
-	}
-}
-#endif
-/**************************************************************************************************
-int DistanceCommand::convertMatrix(string outputFile) {
-	try{
-
-		//sort file by first column so the distances for each row are together
-		string outfile = m->getRootName(outputFile) + "sorted.dist.temp";
-		
-		//use the unix sort 
-		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
-			string command = "sort -n " + outputFile + " -o " + outfile;
-			system(command.c_str());
-		#else //sort using windows sort
-			string command = "sort " + outputFile + " /O " + outfile;
-			system(command.c_str());
-		#endif
-		
-
-		//output to new file distance for each row and save positions in file where new row begins
-		ifstream in;
-		m->openInputFile(outfile, in);
-		
-		ofstream out;
-		m->openOutputFile(outputFile, out);
-		
-		out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
-
-		out << alignDB.getNumSeqs() << endl;
-		
-		//get first currentRow
-		string first, currentRow, second;
-		float dist;
-		map<string, float> rowDists; //take advantage of the fact that maps are already sorted by key 
-		map<string, float>::iterator it;
-		
-		in >> first;
-		currentRow = first;
-		
-		rowDists[first] = 0.00; //distance to yourself is 0.0
-		
-		in.seekg(0);
-		//m->openInputFile(outfile, in);
-		
-		while(!in.eof()) {
-			if (m->control_pressed) { in.close(); m->mothurRemove(outfile); out.close(); return 0; }
-			
-			in >> first >> second >> dist; m->gobble(in);
-				
-			if (first != currentRow) {
-				//print out last row
-				out << currentRow << '\t'; //print name
-
-				//print dists
-				for (it = rowDists.begin(); it != rowDists.end(); it++) {
-					out << it->second << '\t';
-				}
-				out << endl;
-				
-				//start new row
-				currentRow = first;
-				rowDists.clear();
-				rowDists[first] = 0.00;
-				rowDists[second] = dist;
-			}else{
-				rowDists[second] = dist;
-			}
-		}
-		//print out last row
-		out << currentRow << '\t'; //print name
-				
-		//print dists
-		for (it = rowDists.begin(); it != rowDists.end(); it++) {
-			out << it->second << '\t';
-		}
-		out << endl;
-		
-		in.close();
-		out.close();
-		
-		m->mothurRemove(outfile);
-		
-		return 1;
-		
-	}
-	catch(exception& e) {
-		m->errorOut(e, "DistanceCommand", "convertMatrix");
-		exit(1);
-	}
-}
-**************************************************************************************************
-int DistanceCommand::convertToLowerTriangle(string outputFile) {
-	try{
-
-		//sort file by first column so the distances for each row are together
-		string outfile = m->getRootName(outputFile) + "sorted.dist.temp";
-		
-		//use the unix sort 
-		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
-			string command = "sort -n " + outputFile + " -o " + outfile;
-			system(command.c_str());
-		#else //sort using windows sort
-			string command = "sort " + outputFile + " /O " + outfile;
-			system(command.c_str());
-		#endif
-		
-
-		//output to new file distance for each row and save positions in file where new row begins
-		ifstream in;
-		m->openInputFile(outfile, in);
-		
-		ofstream out;
-		m->openOutputFile(outputFile, out);
-		
-		out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
-
-		out << alignDB.getNumSeqs() << endl;
-		
-		//get first currentRow
-		string first, currentRow, second;
-		float dist;
-		int i, j;
-		i = 0; j = 0;
-		map<string, float> rowDists; //take advantage of the fact that maps are already sorted by key 
-		map<string, float>::iterator it;
-		
-		in >> first;
-		currentRow = first;
-		
-		rowDists[first] = 0.00; //distance to yourself is 0.0
-		
-		in.seekg(0);
-		//m->openInputFile(outfile, in);
-		
-		while(!in.eof()) {
-			if (m->control_pressed) { in.close(); m->mothurRemove(outfile); out.close(); return 0; }
-			
-			in >> first >> second >> dist; m->gobble(in);
-				
-			if (first != currentRow) {
-				//print out last row
-				out << currentRow << '\t'; //print name
-
-				//print dists
-				for (it = rowDists.begin(); it != rowDists.end(); it++) {
-					if (j >= i) { break; }
-					out << it->second << '\t';
-					j++;
-				}
-				out << endl;
-				
-				//start new row
-				currentRow = first;
-				rowDists.clear();
-				rowDists[first] = 0.00;
-				rowDists[second] = dist;
-				j = 0;
-				i++;
-			}else{
-				rowDists[second] = dist;
-			}
-		}
-		//print out last row
-		out << currentRow << '\t'; //print name
-				
-		//print dists
-		for (it = rowDists.begin(); it != rowDists.end(); it++) {
-			out << it->second << '\t';
-		}
-		out << endl;
-		
-		in.close();
-		out.close();
-		
-		m->mothurRemove(outfile);
-		
-		return 1;
-		
-	}
-	catch(exception& e) {
-		m->errorOut(e, "DistanceCommand", "convertToLowerTriangle");
-		exit(1);
-	}
-}
-**************************************************************************************************/
 //its okay if the column file does not contain all the names in the fasta file, since some distance may have been above a cutoff,
 //but no sequences can be in the column file that are not in oldfasta. also, if a distance is above the cutoff given then remove it.
 //also check to make sure the 2 files have the same alignment length.
