@@ -35,14 +35,14 @@ vector<string> GetOtuLabelsCommand::setParameters(){
 string GetOtuLabelsCommand::getHelpString(){	
 	try {
 		string helpString = "";
-		helpString += "The get.otulabels command can be used to select specific otus with the output from classify.otu, otu.association, or corr.axes commands.  It can also be used to select a set of otus from a shared or list file.\n";
-		helpString += "The get.otulabels parameters are: constaxonomy, otucorr, corraxes, shared, list, label and accnos.\n";
+		helpString += "The get.otus command can be used to select specific otus with the output from classify.otu, otu.association, or corr.axes commands.  It can also be used to select a set of otus from a shared or list file.\n";
+		helpString += "The get.otus parameters are: constaxonomy, otucorr, corraxes, shared, list, label and accnos.\n";
 		helpString += "The constaxonomy parameter is used to input the results of the classify.otu command.\n";
         helpString += "The otucorr parameter is used to input the results of the otu.association command.\n";
         helpString += "The corraxes parameter is used to input the results of the corr.axes command.\n";
         helpString += "The label parameter is used to analyze specific labels in your input. \n";
-		helpString += "The get.otulabels commmand should be in the following format: \n";
-		helpString += "get.otulabels(accnos=yourListOfOTULabels, corraxes=yourCorrAxesFile)\n";
+		helpString += "The get.otus commmand should be in the following format: \n";
+		helpString += "get.otus(accnos=yourListOfOTULabels, corraxes=yourCorrAxesFile)\n";
 		return helpString;
 	}
 	catch(exception& e) {
@@ -239,7 +239,7 @@ int GetOtuLabelsCommand::execute(){
         set<string> newLabels;
         for (set<string>::iterator it = labels.begin(); it != labels.end(); it++) {  newLabels.insert(m->getSimpleLabel(*it)); }
         labels = newLabels;
-		
+        
 		if (m->control_pressed) { return 0; }
 		
 		//read through the correct file and output lines you want to keep
@@ -307,6 +307,8 @@ int GetOtuLabelsCommand::readClassifyOtu(){
             
             in >> otu >> size >> tax; m->gobble(in);
             
+            if (m->debug) { m->mothurOut("Otu=" + otu + ", size=" + toString(size) + ", tax=" + tax + "\n"); }
+            
             if (labels.count(m->getSimpleLabel(otu)) != 0) {
 				wroteSomething = true;
 				selectedCount++;
@@ -552,7 +554,7 @@ int GetOtuLabelsCommand::readList(){
             wroteSomething = true;
             newList.setLabels(newLabels);
             newList.printHeaders(out);
-            newList.print(out);
+            newList.print(out, false);
         }
 		out.close();
 		
