@@ -1026,8 +1026,14 @@ int MakeBiomCommand::getGreenGenesOTUIDs(vector<SharedRAbundVector*>& lookup, ma
             m->removeConfidences(OTUTaxonomy);
             
             //remove unclassifieds to match template
-            int thisPos = OTUTaxonomy.find("unclassified;");
-            if (thisPos != string::npos) {  OTUTaxonomy = OTUTaxonomy.substr(0, thisPos);  }
+            int thisPos = OTUTaxonomy.find("unclassified;"); //"Porphyromonadaceae"_unclassified;
+            if (thisPos != string::npos) {
+                OTUTaxonomy = OTUTaxonomy.substr(0, thisPos);
+                thisPos = OTUTaxonomy.find_last_of(";"); //remove rest of parent taxon
+                if (thisPos != string::npos) {
+                    OTUTaxonomy = OTUTaxonomy.substr(0, thisPos);
+                }
+            }
             
             //get list of reference ids that map to this taxonomy
             vector<string> referenceIds = phylo.getSeqs(OTUTaxonomy);
@@ -1192,8 +1198,14 @@ int MakeBiomCommand::getGreenGenesOTUIDs(vector<SharedRAbundFloatVector*>& looku
             m->removeConfidences(OTUTaxonomy);
             
             //remove unclassifieds to match template
-            int thisPos = OTUTaxonomy.find("unclassified;");
-            if (thisPos != string::npos) {  OTUTaxonomy = OTUTaxonomy.substr(0, thisPos);  }
+            int thisPos = OTUTaxonomy.find("unclassified;"); //"Porphyromonadaceae"_unclassified;
+            if (thisPos != string::npos) {
+                OTUTaxonomy = OTUTaxonomy.substr(0, thisPos);
+                thisPos = OTUTaxonomy.find_last_of(";"); //remove rest of parent taxon
+                if (thisPos != string::npos) {
+                    OTUTaxonomy = OTUTaxonomy.substr(0, thisPos);
+                }
+            }
             
             //get list of reference ids that map to this taxonomy
             vector<string> referenceIds = phylo.getSeqs(OTUTaxonomy);
@@ -1405,6 +1417,8 @@ int MakeBiomCommand::getSampleMetaData(vector<SharedRAbundVector*>& lookup){
                 
                 string line = m->getline(in); m->gobble(in);
                 vector<string> thisPieces = m->splitWhiteSpaceWithQuotes(line);
+                
+                if (m->debug) {  m->mothurOut("[DEBUG]: " + group + " " + m->getStringFromVector(thisPieces, ", ") + "\n"); }
         
                 if (thisPieces.size() != count) { m->mothurOut("[ERROR]: expected " + toString(count) + " items of data for sample " + group + " read " + toString(thisPieces.size()) + ", quitting.\n"); }
                 else {  if (m->inUsersGroups(group, groups)) { lines[group] = thisPieces; } }
