@@ -498,7 +498,7 @@ int RemoveRareCommand::processList(){
 				wroteSomething = true;
 				newList.setLabels(newLabels);
                 newList.printHeaders(out);
-                newList.print(out);
+                newList.print(out, false);
 			}
 		}	
 		
