@@ -25,7 +25,7 @@ public:
 	string getCommandCategory()		{ return "General";		}
 	
 	string getHelpString();	
-    string getOutputPattern(string){ return ""; }	
+    string getOutputPattern(string);
 	string getCitation() { return "http://www.mothur.org/wiki/Set.current"; }
 	string getDescription()		{ return "set current files for mothur"; }
 
@@ -40,9 +40,10 @@ private:
 	string clearTypes;
 	vector<string> types;
 	
-	string accnosfile, phylipfile, columnfile, listfile, rabundfile, sabundfile, namefile, groupfile, designfile, taxonomyfile, biomfile, countfile, summaryfile;
+	string accnosfile, phylipfile, columnfile, listfile, rabundfile, sabundfile, namefile, groupfile, designfile, taxonomyfile, biomfile, countfile, summaryfile, currentFile, outputDir;
 	string orderfile, treefile, sharedfile, ordergroupfile, relabundfile, fastafile, qualfile, sfffile, oligosfile, processors, flowfile, filefile;
 
+    int readCurrentFiles();
 	
 };
 
