@@ -35,9 +35,12 @@ class SummaryTaxCommand : public Command {
 		
 	private:
 		bool abort, relabund;
-		string taxfile, outputDir, namefile, groupfile, refTaxonomy, countfile;
+		string taxfile, outputDir, namefile, groupfile, countfile, output;
+        int printlevel, threshold;
 		vector<string> outputNames;
 		map<string, int> nameMap;
+    
+        string processTaxMap(string);
 };
 
 /**************************************************************************************************/
