@@ -50,12 +50,13 @@ class CountTable {
         //reads and creates smart enough to eliminate groups with zero counts 
         int createTable(set<string>&, map<string, string>&, set<string>&); //seqNames, seqName->group, groupNames 
         int createTable(string, string, bool); //namefile, groupfile, createGroup
-        int readTable(string, bool, bool);
+        int readTable(string, bool, bool); //file, readGroups, mothurRunning
     
         int printTable(string);
         int printHeaders(ofstream&);
         int printSeq(ofstream&, string);
-        bool testGroups(string file); //used to check if file has group data without reading it.
+        bool testGroups(string file); //used to check if file has group data without reading it
+        bool testGroups(string file, vector<string>&); //used to check if file has group data without reading it, return groups if found.
         int copy(CountTable*);
     
         bool hasGroupInfo() { return hasGroups; }
