@@ -201,6 +201,16 @@ vector<float> SharedRAbundFloatVector::getAbundances(){
 	return abunds;
 }
 /***********************************************************************/
+//returns vector of abundances
+vector<double> SharedRAbundFloatVector::getAbundances(string makeDouble){
+    vector<double> abunds;
+    for (int i = 0; i < data.size(); i++) {
+        abunds.push_back((double)(data[i].abundance));
+    }
+    
+    return abunds;
+}
+/***********************************************************************/
 individualFloat SharedRAbundFloatVector::get(int index){
 	return data[index];	
 }
@@ -402,7 +412,7 @@ vector<SharedRAbundFloatVector*> SharedRAbundFloatVector::getSharedRAbundFloatVe
 		
 		delete util;
 		
-		if (remove) { eliminateZeroOTUS(lookup); }
+		if (remove) { eliminateZeroOTUS(); }
 	
 		return lookup;
 	}
@@ -514,33 +524,33 @@ OrderVector SharedRAbundFloatVector::getOrderVector(map<string,int>* nameMap = N
 	}
 }
 //**********************************************************************************************************************
-int SharedRAbundFloatVector::eliminateZeroOTUS(vector<SharedRAbundFloatVector*>& thislookup) {
+int SharedRAbundFloatVector::eliminateZeroOTUS() {
 	try {
 		
 		vector<SharedRAbundFloatVector*> newLookup;
-		for (int i = 0; i < thislookup.size(); i++) {
+		for (int i = 0; i < lookup.size(); i++) {
 			SharedRAbundFloatVector* temp = new SharedRAbundFloatVector();
-			temp->setLabel(thislookup[i]->getLabel());
-			temp->setGroup(thislookup[i]->getGroup());
+			temp->setLabel(lookup[i]->getLabel());
+			temp->setGroup(lookup[i]->getGroup());
 			newLookup.push_back(temp);
 		}
 		
 		//for each bin
 		vector<string> newBinLabels;
-		string snumBins = toString(thislookup[0]->getNumBins());
-		for (int i = 0; i < thislookup[0]->getNumBins(); i++) {
+		string snumBins = toString(lookup[0]->getNumBins());
+		for (int i = 0; i < lookup[0]->getNumBins(); i++) {
 			if (m->control_pressed) { for (int j = 0; j < newLookup.size(); j++) {  delete newLookup[j];  } return 0; }
 			
 			//look at each sharedRabund and make sure they are not all zero
 			bool allZero = true;
-			for (int j = 0; j < thislookup.size(); j++) {
-				if (thislookup[j]->getAbundance(i) != 0) { allZero = false;  break;  }
+			for (int j = 0; j < lookup.size(); j++) {
+				if (lookup[j]->getAbundance(i) != 0) { allZero = false;  break;  }
 			}
 			
 			//if they are not all zero add this bin
 			if (!allZero) {
-				for (int j = 0; j < thislookup.size(); j++) {
-					newLookup[j]->push_back(thislookup[j]->getAbundance(i), thislookup[j]->getGroup());
+				for (int j = 0; j < lookup.size(); j++) {
+					newLookup[j]->push_back(lookup[j]->getAbundance(i), lookup[j]->getGroup());
 				}
 				//if there is a bin label use it otherwise make one
 				string binLabel = "Otu";
@@ -556,9 +566,9 @@ int SharedRAbundFloatVector::eliminateZeroOTUS(vector<SharedRAbundFloatVector*>&
 			}
 		}
 		
-		for (int j = 0; j < thislookup.size(); j++) {  delete thislookup[j];  }
+		for (int j = 0; j < lookup.size(); j++) {  delete lookup[j];  }
 		
-		thislookup = newLookup;
+		lookup = newLookup;
 		m->currentSharedBinLabels = newBinLabels;
 		
 		return 0;
