@@ -10,13 +10,11 @@
 #include "mothur.h"
 #include "engine.hpp"
 #include "mothurout.h"
-#include "referencedb.h"
 
 /**************************************************************************************************/
 
 CommandFactory* CommandFactory::_uniqueInstance = 0;
 MothurOut* MothurOut::_uniqueInstance = 0;
-ReferenceDB* ReferenceDB::myInstance = 0;
 /***********************************************************************/
 volatile int ctrlc_pressed = 0;
 void ctrlc_handler ( int sig ) {
@@ -42,10 +40,6 @@ int main(int argc, char *argv[]){
 		time_t ltime = time(NULL); /* calendar time */  
 		string logFileName = "mothur." + toString(ltime) + ".logfile";
 		
-		#ifdef USE_MPI
-			MPI_Init(&argc, &argv); 
-		#endif
-
 		m->setFileName(logFileName);
 		
 		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
@@ -69,11 +63,6 @@ int main(int argc, char *argv[]){
 			m->setDefaultPath(temp);
 		#endif
 		
-		#ifdef USE_MPI
-			int version, subversion;
-			MPI_Get_version(&version, &subversion);
-		#endif
-		
 		//get releaseDate from Make
 		string releaseDate = RELEASE_DATE; 
 		string mothurVersion = VERSION; 
@@ -174,12 +163,7 @@ int main(int argc, char *argv[]){
 			m->mothurOutEndLine();
 			m->mothurOutEndLine();			
 			m->mothurOut("Type 'quit()' to exit program");
-			m->mothurOutEndLine();	
-			
-			#ifdef USE_MPI
-				m->mothurOutJustToLog("Using MPI\tversion ");
-				m->mothurOutJustToLog(toString(version) + "." + toString(subversion) + "\n");
-			#endif
+			m->mothurOutEndLine();
 		}
 		
 		//srand(54321);
@@ -223,9 +207,6 @@ int main(int argc, char *argv[]){
                 #endif
                 
 				m->mothurOut(OS + "\nMothur version=" + mothurVersion + "\nRelease Date=" + releaseDate); m->mothurOutEndLine(); m->mothurOutEndLine(); m->closeLog();
-				#ifdef USE_MPI
-					MPI_Finalize();
-				#endif
                 m->mothurRemove(logFileName);
 				return 0;
                 
@@ -292,12 +273,11 @@ int main(int argc, char *argv[]){
         if (!createLogFile) { m->mothurRemove(newlogFileName); }
 				
 		if (mothur != NULL) { delete mothur; }
-		
-		#ifdef USE_MPI
-			MPI_Finalize();
-		#endif
-		
-		return 0;
+        
+        int returnCode = 0;
+        if (m->getNumErrors() != 0) { returnCode = 1; }
+        
+		return returnCode;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "mothur", "main");
